@@ -1,7 +1,7 @@
 #
 # linim.R
 #
-#  $Revision: 1.80 $   $Date: 2021/08/25 08:19:56 $
+#  $Revision: 1.85 $   $Date: 2023/05/04 01:37:22 $
 #
 #  Image/function on a linear network
 #
@@ -30,7 +30,7 @@ linim <- function(L, Z, ..., restrict=TRUE, df=NULL) {
   }
   if(restrict) {
     #' restrict image to pixels actually lying on the network
-    M <- as.mask.psp(as.psp(L), Z)
+    M <- psp2mask(as.psp(L), Z)
     if(dfgiven) {
       #' ensure all mapped pixels are untouched
       pos <- nearest.pixel(df$xc, df$yc, Z)
@@ -190,7 +190,7 @@ plot.linim <- local({
         #' first fatten the lines 
         L <- attr(x, "L")
         S <- as.psp(L)
-        D <- distmap(as.mask.psp(S, xy=x))
+        D <- distmap(psp2mask(S, xy=x))
         fatwin <- levelset(D, fatten)
         x <- nearestValue(x)[fatwin, drop=FALSE]
       }
@@ -367,10 +367,13 @@ as.linim <- function(X, ...) {
 }
 
 as.linim.default <- function(X, L, ..., eps = NULL, dimyx = NULL, xy = NULL,
-                                        delta = NULL, nd = NULL) {
+                             rule.eps=c("adjust.eps",
+                                        "grow.frame", "shrink.frame"),
+                             delta = NULL, nd = NULL) {
   stopifnot(inherits(L, "linnet"))
-  Y <- as.im(X, W=Frame(L), ..., eps=eps, dimyx=dimyx, xy=xy)
-  M <- as.mask.psp(as.psp(L), as.owin(Y))
+  rule.eps <- match.arg(rule.eps)
+  Y <- as.im(X, W=Frame(L), ..., eps=eps, dimyx=dimyx, xy=xy, rule.eps=rule.eps)
+  M <- psp2mask(as.psp(L), as.owin(Y))
   Y[complement.owin(M)] <- NA
   df <- NULL
   if(!is.null(delta) || !is.null(nd)) {
@@ -383,8 +386,10 @@ as.linim.default <- function(X, L, ..., eps = NULL, dimyx = NULL, xy = NULL,
     df <- df[,c("xc", "yc", "x", "y", "seg", "tp", "values")]
     names(df)[names(df) == "seg"] <- "mapXY"
   }
-  if(is.mask(WL <- Window(L)) && !all(sapply(list(eps, dimyx, xy), is.null)))
-     Window(L, check=FALSE) <- as.mask(WL, eps=eps, dimyx=dimyx, xy=xy)
+  if(is.mask(WL <- Window(L)) && !all(sapply(list(eps, dimyx, xy), is.null))) {
+    Window(L, check=FALSE) <- as.mask(WL,
+                              eps=eps, dimyx=dimyx, xy=xy, rule.eps=rule.eps)
+  }
   out <- linim(L, Y, df=df, restrict=FALSE)
   return(out)
 }
@@ -590,7 +595,7 @@ as.linnet.linim <- function(X, ...) {
   changed <- (okx != oky) | (okx & oky & yvalue != xvalue)
   df$values[changed] <- yvalue[changed]
   #' restrict main pixel image to network
-  m <- as.mask.psp(L, as.mask(y))$m
+  m <- psp2mask(L, as.mask(y))$m
   m[pos] <- TRUE
   y$v[!m] <- NA
   #' package up
@@ -600,21 +605,30 @@ as.linnet.linim <- function(X, ...) {
   return(y)
 }
 
-integral.linim <- function(f, domain=NULL, ...){
+integral.linim <- function(f, domain=NULL, weight=NULL, ...){
   verifyclass(f, "linim")
+  if(!is.null(weight))
+    weight <- as.linim(weight, domain(f))
   if(is.tess(domain)) {
     result <- sapply(tiles(domain), integral.linim, f = f)
     if(length(dim(result)) > 1) result <- t(result)
     return(result)
   }
-  if(!is.null(domain)) 
+  if(!is.null(domain)) {
     f <- f[domain]
+    if(!is.null(weight)) weight <- weight[domain]
+  }
   #' extract data
   L <- as.linnet(f)
   ns <- nsegments(L)
   df <- attr(f, "df")
   vals <- df$values
   seg <- factor(df$mapXY, levels=1:ns)
+  #' weight
+  if(!is.null(weight)) {
+    samplepoints <- ppp(df$xc, df$yc, window=Frame(L), check=FALSE)
+    vals <- vals * safelookup(weight, samplepoints)
+  }
   #' ensure each segment has at least one sample point
   nper <- table(seg)
   if(any(missed <- (nper == 0))) {
@@ -622,6 +636,8 @@ integral.linim <- function(f, domain=NULL, ...){
     mp <- midpoints.psp(as.psp(L)[missed])
     #' nearest pixel value
     valmid <- safelookup(f, mp)
+    if(!is.null(weight))
+      valmid <- valmid * safelookup(weight, mp)
     #' concatenate factors
     seg <- unlist(list(seg, factor(missed, levels=1:ns)))
     vals <- c(vals, valmid)
@@ -658,7 +674,7 @@ quantile.linim <- function(x, probs = seq(0,1,0.25), ...) {
   vals <- df$values
   #' count sample points on each segment
   seg <- factor(df$mapXY, levels=1:nsegments(L))
-  nvals <- table(seg)
+  nvals <- as.integer(table(seg))
   #' calculate weights
   len <- lengths_psp(as.psp(L))
   iseg <- as.integer(seg)
@@ -666,6 +682,25 @@ quantile.linim <- function(x, probs = seq(0,1,0.25), ...) {
   return(weighted.quantile(vals, wts, probs))
 }
 
+quantilefun.linim <- function(x, ..., type=1) {
+  verifyclass(x, "linim")
+  #' extract data
+  df <- attr(x, "df")
+  L <- as.linnet(x)
+  vals <- df$values
+  #' count sample points on each segment
+  seg <- factor(df$mapXY, levels=1:nsegments(L))
+  nvals <- as.integer(table(seg))
+  #' calculate weights
+  len <- lengths_psp(as.psp(L))
+  iseg <- as.integer(seg)
+  wts <- len[iseg]/nvals[iseg]
+  #' form weighted CDF
+  FZ <- ewcdf(vals, wts)
+  #' quantile function
+  return(quantilefun(FZ, type=type))
+}
+
 median.linim <- function(x, ...) {
   trap.extra.arguments(...)
   return(unname(quantile(x, 0.5)))
